<?php
namespace Ep\Woo\Plugin\Order;

use Ep\Wp\Plugin\PluginInterface;

/**
 * Dodajemo custom statuse narudžbi potrebne Gathu.
 *
 * @package Ep\Woo\Order
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-woocommerce
 */
class CustomStatus implements PluginInterface
{
    /**
     * Dodaje akcije i filtere u WordPress.
     *
     * @return void
     */
    public function __invoke(): void
    {
        add_action('init', [$this, 'init']);
        add_filter('rest_pre_dispatch', [$this, 'rest_pre_dispatch'], 10, 3);
        add_filter('wc_order_statuses', [$this, 'wc_order_statuses']);
    }

    /**
     * Inicijalizacija.
     */
    public function init(): void
    {
        register_post_status('wc-cekanje-uplate', [
            'label' => 'Čekanje uplate',
            'public' => true,
            'exclude_from_search' => false,
            'show_in_admin_all_list' => true,
            'show_in_admin_status_list' => true,
            'label_count' => 'Čeka se uplata <span class="count">(%s)</span>',
        ]);

        register_post_status('wc-pakiranje', [
            'label' => 'Pakiranje',
            'public' => true,
            'exclude_from_search' => false,
            'show_in_admin_all_list' => true,
            'show_in_admin_status_list' => true,
            'label_count' => 'U pakiranju <span class="count">(%s)</span>',
        ]);
    }

    /**
     * Mijenja request prije nego što udari REST api.
     *
     * @param $null
     * @param $server
     * @param \WP_REST_Request $request
     *
     * @return mixed
     */
    public function rest_pre_dispatch($null, /** @noinspection PhpUnusedParameterInspection */ $server, \WP_REST_Request $request)
    {
        if (preg_match('#/wc/v2/orders/\d+$#', $request->get_route()) && 'PUT' === $_SERVER['REQUEST_METHOD']) {
            $body = json_decode($request->get_body(), true);
            if (isset($body['status']) && 'ekanje-uplate' === $body['status']) {
                $body['status'] = 'cekanje-uplate';
                $request->set_body(json_encode($body));
            }
        }

        return $null;
    }

    /**
     * Filtrira statuse narudžbi.
     *
     * @param array $statuses
     *
     * @return array
     */
    public function wc_order_statuses(array $statuses): array
    {
        $new = [];

        foreach ($statuses as $name => $status) {
            $new[$name] = $status;

            // Naše statuse dodajemo nakon 'Na čekanju'
            if ('wc-on-hold' === $name) {
                $new['wc-cekanje-uplate'] = 'Čekanje uplate';
                $new['wc-pakiranje']      = 'Pakiranje';
            }
        }

        return $new;
    }
}