<?php
namespace Ep\Woo\Plugin\Product;

use Ep\Wp\Plugin\PluginInterface;

/**
 * Sakriva cijene ako korisnik nije ulogiran.
 *
 * @package Ep\Woo\Plugin\Product
 * @author Elektronika Perhoč <support@ep.hr>
 * @link https://bitbucket.org/elektronika-perhoc/ep-wordpress
 */
class LoginForPrices implements PluginInterface
{
    /**
     * Dodaje akcije i filtere u WordPress.
     *
     * @return void
     */
    public function __invoke(): void
    {
        add_filter('woocommerce_product_get_price', [$this, 'wc_product_get_price']);
        add_filter('woocommerce_variation_prices_price', [$this, 'wc_product_get_price']);
        add_filter('woocommerce_variation_prices_regular_price', [$this, 'wc_product_get_price']);
        add_filter('woocommerce_variation_prices_sale_price', [$this, 'wc_product_get_price']);

        add_filter('woocommerce_empty_price_html', [$this, 'wc_empty_price_html']);
        add_filter('woocommerce_grouped_empty_price_html', [$this, 'wc_empty_price_html']);
        add_filter('woocommerce_variable_empty_price_html', [$this, 'wc_empty_price_html']);
    }

    /**
     * Ako korisnik nije ulogiran vraća prazan string umjesto cijene.
     *
     * @param string $price
     *
     * @return string
     */
    public function wc_product_get_price(string $price): string
    {
        if (0 === get_current_user_id()) {
            return '';
        }

        return $price;
    }

    /**
     * Vraća link za login kada je cijena proizvoda prazna.
     *
     * @return string
     */
    public function wc_empty_price_html(): string
    {
        return sprintf(
            '<a href="%s">%s</a>',
            get_permalink(get_option('woocommerce_myaccount_page_id')),
            'Login za cijene'
        );
    }
}